@@ -35,6 +35,7 @@
 #include "ephy-lockdown.h"
 #include "ephy-prefs.h"
 #include "ephy-private.h"
+#include "ephy-search-provider.h"
 #include "ephy-session.h"
 #include "ephy-settings.h"
 #include "ephy-type-builtins.h"
@@ -53,6 +54,7 @@
 #define EPHY_SHELL_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_SHELL, EphyShellPrivate))
 
 struct _EphyShellPrivate {
+  EphySearchProvider *search_provider;
   EphySession *session;
   GList *windows;
   GObject *lockdown;
@@ -295,6 +297,20 @@ session_load_cb (GObject *object,
   ephy_shell_startup_continue (shell);
 }
 
+static void
+ephy_shell_start_headless (EphyShell *shell)
+{
+  /* A bit of a hack: because we don't pass IS_SERVICE to GApplication
+     (because otherwise we would need a separate launcher binary), we
+     don't get the 10 seconds timeout for the first DBus call.
+     So just hold/release to get the inactivity timeout started instead.
+  */
+
+  g_application_hold (G_APPLICATION (shell));
+  g_application_release (G_APPLICATION (shell));
+  ephy_shell_startup_continue (shell);
+}
+
 static void
 ephy_shell_activate (GApplication *application)
 {
@@ -302,15 +318,18 @@ ephy_shell_activate (GApplication *application)
 
   /*
    * We get here on each new instance (remote or not). Autoresume the
-   * session unless we are in application mode and queue the
+   * session unless we are in application or headless mode and queue the
    * commands.
    */
   if (ephy_embed_shell_get_mode (EPHY_EMBED_SHELL (shell)) != EPHY_EMBED_SHELL_MODE_APPLICATION) {
     EphyShellStartupContext *ctx;
 
     ctx = shell->priv->startup_context;
-    ephy_session_resume (ephy_shell_get_session (shell),
-                         ctx->user_time, NULL, session_load_cb, shell);
+    if (ctx->startup_flags != EPHY_STARTUP_OPEN_NOTHING)
+      ephy_session_resume (ephy_shell_get_session (shell),
+                           ctx->user_time, NULL, session_load_cb, shell);
+    else
+      ephy_shell_start_headless (shell);
   } else
     ephy_shell_startup_continue (shell);
 }
@@ -502,6 +521,42 @@ ephy_shell_constructed (GObject *object)
     G_OBJECT_CLASS (ephy_shell_parent_class)->constructed (object);
 }
 
+static gboolean
+ephy_shell_dbus_register (GApplication    *application,
+                          GDBusConnection *connection,
+                          const gchar     *object_path,
+                          GError         **error)
+{
+  EphyShell *self;
+
+  if (!G_APPLICATION_CLASS (ephy_shell_parent_class)->dbus_register (application,
+                                                                     connection,
+                                                                     object_path,
+                                                                     error))
+    return FALSE;
+
+  self = EPHY_SHELL (application);
+
+  return ephy_search_provider_dbus_register (self->priv->search_provider, connection,
+                                             object_path, error);
+}
+
+static void
+ephy_shell_dbus_unregister (GApplication    *application,
+                            GDBusConnection *connection,
+                            const gchar     *object_path)
+{
+  EphyShell *self;
+
+  self = EPHY_SHELL (application);
+  if (self->priv->search_provider)
+    ephy_search_provider_dbus_unregister (self->priv->search_provider, connection, object_path);
+
+  G_APPLICATION_CLASS (ephy_shell_parent_class)->dbus_unregister (application,
+                                                                  connection,
+                                                                  object_path);
+}
+
 static void
 ephy_shell_class_init (EphyShellClass *klass)
 {
@@ -516,6 +571,8 @@ ephy_shell_class_init (EphyShellClass *klass)
   application_class->activate = ephy_shell_activate;
   application_class->before_emit = ephy_shell_before_emit;
   application_class->add_platform_data = ephy_shell_add_platform_data;
+  application_class->dbus_register = ephy_shell_dbus_register;
+  application_class->dbus_unregister = ephy_shell_dbus_unregister;
 
   g_type_class_add_private (object_class, sizeof(EphyShellPrivate));
 }
@@ -597,6 +654,10 @@ ephy_shell_init (EphyShell *shell)
   webkit_web_context_set_favicon_database_directory (web_context, favicon_db_path);
   g_free (favicon_db_path);
 #endif
+
+  shell->priv->search_provider = ephy_search_provider_new ();
+
+  g_application_set_inactivity_timeout (G_APPLICATION (shell), 60 * 1000);
 }
 
 static void
@@ -606,6 +667,7 @@ ephy_shell_dispose (GObject *object)
 
   LOG ("EphyShell disposing");
 
+  g_clear_object (&priv->search_provider);
   g_clear_object (&priv->session);
   g_clear_object (&priv->lockdown);
   g_clear_pointer (&priv->bme, gtk_widget_destroy);
